Author: gabor
Date: Wed Apr 17 11:45:15 2013
New Revision: 249585
URL: http://svnweb.freebsd.org/changeset/base/249585

Log:
  - Corrrect mispellings of word useful
  
  Submitted by: Christoph Mallon <christoph.mal...@gmx.de> (via private mail)

Modified:
  head/sys/cam/cam_periph.h
  head/sys/dev/bktr/CHANGELOG.TXT
  head/sys/dev/bktr/bktr_os.c
  head/sys/dev/ppbus/ppbconf.c
  head/sys/dev/sound/pcm/dsp.c
  head/sys/netinet/tcp_subr.c
  head/sys/pci/ncr.c

Modified: head/sys/cam/cam_periph.h
==============================================================================
--- head/sys/dev/bktr/bktr_os.c Wed Apr 17 11:43:46 2013        (r249584)
+++ head/sys/dev/bktr/bktr_os.c Wed Apr 17 11:45:15 2013        (r249585)
@@ -404,7 +404,7 @@ bktr_attach( device_t dev )
 
 #if defined( BKTR_SIS_VIA_MODE )
        if (bootverbose) printf("Using SiS/VIA chipset compatibilty mode\n");
-        fun = fun | 4; /* Enable SiS/VIA compatibility mode (usefull for
+        fun = fun | 4; /* Enable SiS/VIA compatibility mode (useful for
                            OPTi chipset motherboards too */
 #endif
        pci_write_config(dev, 0x40, fun, 2);

Modified: head/sys/dev/ppbus/ppbconf.c
==============================================================================
--- head/sys/dev/ppbus/ppbconf.c        Wed Apr 17 11:43:46 2013        
(r249584)
+++ head/sys/dev/ppbus/ppbconf.c        Wed Apr 17 11:45:15 2013        
(r249585)
@@ -531,7 +531,7 @@ ppb_request_bus(device_t bus, device_t d
 
                        /* restore the context of the device
                         * The first time, ctx.valid is certainly false
-                        * then do not change anything. This is usefull for
+                        * then do not change anything. This is useful for
                         * drivers that do not set there operating mode
                         * during attachement
                         */

Modified: head/sys/dev/sound/pcm/dsp.c
==============================================================================
--- head/sys/dev/sound/pcm/dsp.c        Wed Apr 17 11:43:46 2013        
(r249584)
+++ head/sys/dev/sound/pcm/dsp.c        Wed Apr 17 11:45:15 2013        
(r249585)
@@ -2011,7 +2011,7 @@ dsp_ioctl(struct cdev *i_dev, u_long cmd
         * OSSv4 docs:  "All errors and counters will automatically be
         * cleared to zeroes after the call so each call will return only
         * the errors that occurred after the previous invocation. ... The
-        * play_underruns and rec_overrun fields are the only usefull fields
+        * play_underruns and rec_overrun fields are the only useful fields
         * returned by OSS 4.0."
         */
                {

Modified: head/sys/netinet/tcp_subr.c
==============================================================================
--- head/sys/netinet/tcp_subr.c Wed Apr 17 11:43:46 2013        (r249584)
+++ head/sys/netinet/tcp_subr.c Wed Apr 17 11:45:15 2013        (r249585)
@@ -1060,7 +1060,7 @@ tcp_drain(void)
         * XXX: The "Net/3" implementation doesn't imply that the TCP
         *      reassembly queue should be flushed, but in a situation
         *      where we're really low on mbufs, this is potentially
-        *      usefull.
+        *      useful.
         */
                INP_INFO_RLOCK(&V_tcbinfo);
                LIST_FOREACH(inpb, V_tcbinfo.ipi_listhead, inp_list) {

Modified: head/sys/pci/ncr.c
==============================================================================
--- head/sys/pci/ncr.c  Wed Apr 17 11:43:46 2013        (r249584)
+++ head/sys/pci/ncr.c  Wed Apr 17 11:45:15 2013        (r249585)
@@ -4857,7 +4857,7 @@ static void ncr_getsync(ncb_p np, u_char
        */
        fak = (kpc - 1) / div_10M[div] + 1;
 
-#if 0  /* You can #if 1 if you think this optimization is usefull */
+#if 0  /* You can #if 1 if you think this optimization is useful */
 
        per = (fak * div_10M[div]) / clk;
 
_______________________________________________
svn-src-all@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"

Reply via email to
--- head/sys/cam/cam_periph.h   Wed Apr 17 11:43:46 2013        (r249584)
+++ head/sys/cam/cam_periph.h   Wed Apr 17 11:45:15 2013        (r249585)
@@ -90,7 +90,7 @@ typedef enum {
        CAM_PERIPH_BIO
 } cam_periph_type;
 
 /* Generically usefull offsets into the peripheral private area */
 #define ppriv_ptr0 periph_priv.entries[0].ptr
 #define ppriv_ptr1 periph_priv.entries[1].ptr
 #define ppriv_field0 periph_priv.entries[0].field

Modified: head/sys/dev/bktr/CHANGELOG.TXT
==============================================================================
--- head/sys/dev/bktr/CHANGELOG.TXT     Wed Apr 17 11:43:46 2013        
(r249584)
+++ head/sys/dev/bktr/CHANGELOG.TXT     Wed Apr 17 11:45:15 2013        
(r249585)
@@ -285,7 +285,7 @@
                     Fix row=0/columns=0 bug. From Randal 
Hopper<aa...@ipass.net>
                     Add option to block the reset of the MSP34xx audio chip by
                     adding options BKTR_NO_MSP_RESET to the kernel config file.
-                    This is usefull if you run another operating system
+                    This is useful if you run another operating system
                     first to initialise the audio chip, then do a soft reboot.
                     Added for Yuri Gindin <y...@xpert.com>
 
@@ -90,7 +90,7 @@ typedef enum {
 } cam_periph_type;
 
-/* Generically usefull offsets into the peripheral private area */
+/* Generically useful offsets into the peripheral private area */
 #define ppriv_ptr0 periph_priv.entries[0].ptr
 #define ppriv_ptr1 periph_priv.entries[1].ptr

Modified: head/sys/dev/bktr/bktr_os.c
==============================================================================